
Package radical.meta
====================

This Python package has only one purpose, to pull the complete RCT software
stack as dependencies.


License
-------

This software is released under the
[LGPL License v3.0](http://opensource.org/licenses/LGPL-3.0).

